import { select } from "d3";
import {} from "./createNodes.js";
import { Layout } from "./Layout.js";
export function createLinks(paper, defs) {
    let link = paper
        .append("g")
        .classed("links", true)
        .attr("stroke", "#999")
        .selectAll("line")
        .data([]);
    return {
        get links() {
            return link;
        },
        updateData(data) {
            link = link
                .data(data, (d) => [d.source, d.target])
                .join((enter) => enter
                .append("line")
                .classed("link", true)
                .attr("opacity", Layout.link.opacity)
                .attr("marker-end", `url(#${defs.defs.arrowHead})`));
        },
        update() {
            this.links.each(function update(datum) {
                const link = select(this);
                const target = datum.target;
                const source = datum.source;
                const dx = target.x - source.x;
                const dy = target.y - source.y;
                const distance = Math.sqrt(dx * dx + dy * dy);
                const offsetX = (dx * Layout.node.radius) / distance;
                const offsetY = (dy * Layout.node.radius) / distance;
                link
                    .attr("x1", source.x + offsetX)
                    .attr("y1", source.y + offsetY)
                    .attr("x2", target.x - offsetX)
                    .attr("y2", target.y - offsetY);
            });
        },
        highlight(source) {
            this.links.attr("opacity", (o) => o.source === source ? Layout.link.hoverOpacity : Layout.link.opacity);
        },
        resetHighlight() {
            this.links.attr("opacity", Layout.link.opacity);
        },
    };
}
//# sourceMappingURL=createLinks.js.map